class RolesController < ApplicationController
  model_data_store(Role)

  def create
    role = Role.new(model_params)
    if role.save
      role.reload
      render json: {role: role, permissions: role.role_permissions}, status: :created
    else
      render json: role.errors, status: :unprocessable_entity
    end
  end

  def update
    if @model.update(model_params)
      @model.reload
      render json: {role: @model, permissions: @model.role_permissions}, status: :ok
    else
      render json: role.errors, status: :unprocessable_entity
    end
  end

  private

  # Use callbacks to share common setup or constraints between actions.
  def set_target
    @model = if params[:user_id]
      User.find(params[:user_id]).role
    else
      Role.find(params[:id])
    end
  end

  # Never trust parameters from the scary internet, only allow the white list through.
  def model_params
    params.require(:role).permit(:name, role_permissions_attributes: [:id, :permitted, :component_permission_id, :role_id])
  end
end
