import * as React from 'react';
import {ModelForm, ModelInput, ModelSelect} from "@rx-suite/ui";
import {LinearProgress} from "@material-ui/core";
import {t, Trans} from "@lingui/macro";
import {Model} from "@rx-suite/data";
import {observer} from "mobx-react-lite";

type Props = {
    model: Model
}

export const LogSettings: React.FunctionComponent<Props> = observer(({model}) => {
    if (!model.reachable) {
        return <Trans>Module must be online to modify Log Settings</Trans>;
    }

    const loggerConfig = model.loggerConfig as Model;

    if (model.loggerConfigState === "missing" || model.loggerConfigState === "fetching") {
        return <LinearProgress/>
    }

    if (model.loggerConfigState === "none") {
        return <Trans>Module does not support configuring Log Settings remotely</Trans>;
    }

    return (
        <ModelForm model={loggerConfig} suppressWrapper>
            <ModelInput name={"location"}/>
            <ModelSelect name={"level"} options={[
                {label: t`DEBUG`, value: "DEBUG"},
                {label: t`INFO`, value: "INFO"},
                {label: t`WARN`, value: "WARN"},
                {label: t`ERROR`, value: "ERROR"},
                {label: t`FATAL`, value: "FATAL"},
                {label: t`UNKNOWN`, value: "UNKNOWN"}
            ]}/>
            <ModelInput type="number" name={"archive_count"}/>
            <ModelInput type="number" name={"max_size"}/>
        </ModelForm>
    )
});